import React, { useState, useEffect } from 'react';
import { Text, View, StyleSheet, Button, TextInput } from 'react-native';
import { BarCodeScanner } from 'expo-barcode-scanner';
import Constants from 'expo-constants';
import { ImageBackground } from 'react-native';
import Styles from '../styles/Style';

export default function App() {
  const [hasPermission, setHasPermission] = useState(false);
  const [scanned, setScanned] = useState(false);
  const [manualEntry, setManualEntry] = useState(false);
  const [barcodeData, setBarcodeData] = useState('');
  const [itemName, setItemName] = useState('');
  const [itemPrice, setItemPrice] = useState('');

  useEffect(() => {
    const getBarCodeScannerPermissions = async () => {
      const { status } = await BarCodeScanner.requestPermissionsAsync();
      const isPermissionGranted = status === 'granted';
      setHasPermission(isPermissionGranted);

      if (!isPermissionGranted) {
        setManualEntry(true);
      }
    };
    getBarCodeScannerPermissions();
  }, []);

  const extractDataFromBarcode = (data) => {
    const [name, price] = data.split('-');
    console.log(name, ' ', price);
    setItemName(name);
    setItemPrice(price);
    console.log(name, ' ', price);
  };

  const sendPostRequest = () => {
    const apiUrl = Constants.expoConfig.extra.apiUrl;

    const newItem = {
      name: itemName,
      price: parseInt(itemPrice),
    };
    console.log(newItem);
    fetch(`${apiUrl}/items/`, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(newItem),
    })
      .then((response) => {
        if (!response.ok) {
          throw new Error('response not valid');
        }
        return response.json();
      })
      .then((data) => {
        console.log('Item added:', data);
        alert('The item has been added to the basket');
        setItemName('');
        setItemPrice('');
      })
      .catch((error) => {
        console.error('Error requesting the API:', error);
      });
  };

  const handleBarCodeScanned = ({ type, data }) => {
    setScanned(true);
    alert(`Bar code with type ${type} and data ${data} has been scanned!`);
    setBarcodeData(data);
    extractDataFromBarcode(data);
  };

  const handleAddToBasket = () => {
    extractDataFromBarcode(barcodeData);
    sendPostRequest();
  };

  return (
    <View style={Styles.container}>
      {manualEntry === false && (
        <Button
          title="Manual Entry"
          onPress={() => setManualEntry(true)}
          style={Styles.topButton}
        />
      )}
      {hasPermission === null ? (
        <Text>Requesting camera permission</Text>
      ) : hasPermission === false ? (
        <Text>No access to camera</Text>
      ) : manualEntry === true ? (
        <ImageBackground
          source={require('../assets/backCard.jpg')}
          style={{ ...Styles.cardBackground, width: '100%' }}
        >
          <View style={Styles.cardContainer}>
            <View style={Styles.card}>
              <View style={Styles.fieldContainer}>
                <Text>Barcode Data:</Text>
                <TextInput
                  style={Styles.textInput}
                  placeholder="Enter barcode data"
                  value={barcodeData}
                  onChangeText={(text) => setBarcodeData(text)}
                />
              </View>
              <Button title="Add to Basket" onPress={handleAddToBasket} />
              <Button title="Cancel" onPress={() => setManualEntry(false)} />
            </View>
          </View>
        </ImageBackground>
      ) : (
        <View style={Styles.barcodeScannerContainer}>
          <BarCodeScanner
            onBarCodeScanned={scanned ? undefined : handleBarCodeScanned}
            style={StyleSheet.absoluteFillObject}
          />
          {scanned && <Button title={'Tap to Scan Again'} onPress={() => setScanned(false)} />}
        </View>
      )}
    </View>
  );
}
